# Info 
[m6a](https://aws.amazon.com/ec2/instance-types/m6a/):
- M6a instances are powered by 3rd generation AMD EPYC processors (code named Milan) with an all-core turbo frequency of 3.6 GHz and include support for AMD Transparent Single Key Memory Encryption (TSME), which encrypts data in physical memory. M6a instances also support new Advanced Vector Extension (AVX-2) instructions for faster execution of cryptographic algorithms.


---
## History
1. [link](https://www.cpubenchmark.net/cpu.php?cpu=Intel+Xeon+Platinum+8375C+%40+2.90GHz&id=4486)
2. 